==> kubernetes-model-1.0.33-sources.jar: io/fabric8/kubernetes/api/model/ContainerStateWaitingBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class ContainerStateWaitingBuilder extends ContainerStateWaitingFluentImpl<ContainerStateWaitingBuilder> implements VisitableBuilder<ContainerStateWaiting,ContainerStateWaitingBuilder>{

     ContainerStateWaitingFluent<?> fluent;
public ContainerStateWaitingBuilder(){
    this(new ContainerStateWaiting());
}
public ContainerStateWaitingBuilder( ContainerStateWaitingFluent<?> fluent ){
    this(fluent, new ContainerStateWaiting());
}
public ContainerStateWaitingBuilder( ContainerStateWaitingFluent<?> fluent , ContainerStateWaiting instance ){
    this.fluent = fluent; fluent.withReason(instance.getReason()); 
}
public ContainerStateWaitingBuilder( ContainerStateWaiting instance ){
    this.fluent = this; this.withReason(instance.getReason()); 
}

public EditableContainerStateWaiting build(){
    EditableContainerStateWaiting buildable = new EditableContainerStateWaiting(fluent.getReason());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ContainerStateWaitingBuilder that = (ContainerStateWaitingBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.36-sources.jar: io/fabric8/kubernetes/api/model/ContainerStateWaitingBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class ContainerStateWaitingBuilder extends ContainerStateWaitingFluentImpl<ContainerStateWaitingBuilder> implements VisitableBuilder<ContainerStateWaiting,ContainerStateWaitingBuilder>{

     ContainerStateWaitingFluent<?> fluent;
public ContainerStateWaitingBuilder(){
    this(new ContainerStateWaiting());
}
public ContainerStateWaitingBuilder( ContainerStateWaitingFluent<?> fluent ){
    this(fluent, new ContainerStateWaiting());
}
public ContainerStateWaitingBuilder( ContainerStateWaitingFluent<?> fluent , ContainerStateWaiting instance ){
    this.fluent = fluent; fluent.withMessage(instance.getMessage()); fluent.withReason(instance.getReason()); 
}
public ContainerStateWaitingBuilder( ContainerStateWaiting instance ){
    this.fluent = this; this.withMessage(instance.getMessage()); this.withReason(instance.getReason()); 
}

public EditableContainerStateWaiting build(){
    EditableContainerStateWaiting buildable = new EditableContainerStateWaiting(fluent.getMessage(),fluent.getReason());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ContainerStateWaitingBuilder that = (ContainerStateWaitingBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
